
From: Andrew Morton <akpm@osdl.org>

fs/asfs/file.c: In function `asfs_get_block':
fs/asfs/file.c:44: warning: long int format, different type arg (arg 2)
fs/asfs/file.c:47: warning: long int format, different type arg (arg 2)


fs/asfs/adminspace.c: In function `asfs_findspace':
fs/asfs/adminspace.c:100: warning: useless keyword or type name in empty declaration
fs/asfs/adminspace.c:100: warning: empty declaration
fs/asfs/adminspace.c:121: parse error before `='
fs/asfs/adminspace.c:185: parse error before `='

(local variable breakpoint clashes with a function in the kgdb patch)



Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 fs/asfs/adminspace.c |   20 ++++++++++----------
 fs/asfs/file.c       |    4 ++--
 2 files changed, 12 insertions(+), 12 deletions(-)

diff -puN fs/asfs/file.c~asfs-filesystem-driver-fixes fs/asfs/file.c
--- 25/fs/asfs/file.c~asfs-filesystem-driver-fixes	2005-06-25 01:55:59.000000000 -0700
+++ 25-akpm/fs/asfs/file.c	2005-06-25 01:56:31.000000000 -0700
@@ -41,10 +41,10 @@ asfs_get_block(struct inode *inode, sect
 	asfs_debug("ASFS: get_block(%lu, %ld, %d)\n", inode->i_ino, block, create);
 
 	if (block < 0) {
-		printk(KERN_ERR "ASFS: asfsget_block: requested block (%ld) < 0!\n", block);
+		printk(KERN_ERR "ASFS: asfsget_block: requested block (%lld) < 0!\n", (unsigned long long)block);
 		return -EIO;
 	} else if (block >= inode->i_blocks && !create) {
-		printk(KERN_ERR "ASFS: asfsget_block: strange block request %ld!\n", block);
+		printk(KERN_ERR "ASFS: asfsget_block: strange block request %lld!\n", (unsigned long long)block);
 		return -EIO;
 	}
 
diff -puN fs/asfs/adminspace.c~asfs-filesystem-driver-fixes fs/asfs/adminspace.c
--- 25/fs/asfs/adminspace.c~asfs-filesystem-driver-fixes	2005-06-25 01:56:54.000000000 -0700
+++ 25-akpm/fs/asfs/adminspace.c	2005-06-25 01:57:59.000000000 -0700
@@ -97,7 +97,7 @@ int asfs_findspace(struct super_block *s
 	u32 space = 0;
 	u32 block;
 	u32 bitmapblock = ASFS_SB(sb)->bitmapbase + start / ASFS_SB(sb)->blocks_inbitmap;
-	u32 breakpoint;
+	u32 break_point;
 	int bitstart, bitend;
 	int reads;
 
@@ -118,7 +118,7 @@ int asfs_findspace(struct super_block *s
 	if (start >= end)
 		reads += (ASFS_SB(sb)->totalblocks - 1) / ASFS_SB(sb)->blocks_inbitmap + 1;
 
-	breakpoint = (start < end ? end : ASFS_SB(sb)->totalblocks);
+	break_point = (start < end ? end : ASFS_SB(sb)->totalblocks);
 
 	*returned_block = 0;
 	*returned_blocks = 0;
@@ -128,10 +128,10 @@ int asfs_findspace(struct super_block *s
 
 	while ((bh = asfs_breadcheck(sb, bitmapblock++, ASFS_BITMAP_ID))) {
 		struct fsBitmap *b = (void *) bh->b_data;
-		u32 localbreakpoint = breakpoint - block;
+		u32 localbreak_point = break_point - block;
 
-		if (localbreakpoint > ASFS_SB(sb)->blocks_inbitmap)
-			localbreakpoint = ASFS_SB(sb)->blocks_inbitmap;
+		if (localbreak_point > ASFS_SB(sb)->blocks_inbitmap)
+			localbreak_point = ASFS_SB(sb)->blocks_inbitmap;
 
 		/* At this point space contains the amount of free blocks at
 		   the end of the previous bitmap block.  If there are no
@@ -141,7 +141,7 @@ int asfs_findspace(struct super_block *s
 		while ((bitstart = bmffo(b->bitmap, longs, bitend)) < ASFS_SB(sb)->blocks_inbitmap) {
 			/* found the start of an empty space, now find out how large it is */
 
-			if (bitstart >= localbreakpoint)
+			if (bitstart >= localbreak_point)
 				break;
 
 			if (bitstart != 0)
@@ -149,8 +149,8 @@ int asfs_findspace(struct super_block *s
 
 			bitend = bmffz(b->bitmap, longs, bitstart);
 
-			if (bitend > localbreakpoint)
-				bitend = localbreakpoint;
+			if (bitend > localbreak_point)
+				bitend = localbreak_point;
 
 			space += bitend - bitstart;
 
@@ -164,7 +164,7 @@ int asfs_findspace(struct super_block *s
 				*returned_blocks = space;
 			}
 
-			if (bitend >= localbreakpoint)
+			if (bitend >= localbreak_point)
 				break;
 		}
 
@@ -182,7 +182,7 @@ int asfs_findspace(struct super_block *s
 		if (block >= ASFS_SB(sb)->totalblocks) {
 			block = 0;
 			space = 0;
-			breakpoint = end;
+			break_point = end;
 			bitmapblock = ASFS_SB(sb)->bitmapbase;
 		}
 		asfs_brelse(bh);
_
